@@ -1,6 +1,7 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,11 +15,15 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 #ifndef __LIBGCMD_DEPS_H__
 #define __LIBGCMD_DEPS_H__
 
+#include <glib.h>
+
+G_BEGIN_DECLS
 
 #include <gdk/gdk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -31,5 +36,6 @@
 
 extern GtkWidget *main_win_widget;
 
+G_END_DECLS
 
 #endif //__LIBGCMD_DEPS_H__
