@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,18 +23,18 @@
 #include "gnome-cmd-cmdline.h"
 #include "gnome-cmd-combo.h"
 #include "gnome-cmd-style.h"
-#include "utils.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-main-win.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-dir.h"
+#include "utils.h"
 
 using namespace std;
 
 
 static GtkHBoxClass *parent_class = NULL;
 
-struct _GnomeCmdCmdlinePrivate
+struct GnomeCmdCmdlinePrivate
 {
     GtkWidget *combo;
     GtkWidget *cwd;
@@ -63,10 +64,7 @@ inline void update_history_combo (GnomeCmdCmdline *cmdline)
 
 inline void add_to_history (GnomeCmdCmdline *cmdline, const gchar *command)
 {
-    cmdline->priv->history = string_history_add (
-        cmdline->priv->history,
-        command,
-        gnome_cmd_data_get_cmdline_history_length());
+    cmdline->priv->history = string_history_add (cmdline->priv->history, command, gnome_cmd_data.cmdline_history_length);
 
     update_history_combo (cmdline);
 }
@@ -87,26 +85,25 @@ static void on_exec (GnomeCmdCmdline *cmdline, gboolean term)
 
         if (strcmp (dest_dir, "-")==0)
         {
-            GnomeVFSURI *test_uri = gnome_cmd_dir_get_child_uri (gnome_cmd_file_selector_get_directory (fs), "-");
+            GnomeVFSURI *test_uri = gnome_cmd_dir_get_child_uri (fs->get_directory(), "-");
 
             if (gnome_vfs_uri_exists (test_uri))
-                gnome_cmd_file_selector_goto_directory (fs, dest_dir);
+                fs->goto_directory(dest_dir);
             else
-                gnome_cmd_file_selector_back (fs);
+                fs->back();
 
             gnome_vfs_uri_unref (test_uri);
         }
         else
-            gnome_cmd_file_selector_goto_directory (fs, dest_dir);
+            fs->goto_directory(dest_dir);
     }
     else
         if (strcmp (cmdline_text, "cd")==0)
-            gnome_cmd_file_selector_goto_directory (fs, "~");
+            fs->goto_directory("~");
         else
-            if (gnome_cmd_con_is_local (gnome_cmd_file_selector_get_connection (fs)))
+            if (fs->is_local())
             {
-                GnomeCmdDir *dir = gnome_cmd_file_selector_get_directory (fs);
-                gchar *fpath = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dir));
+                gchar *fpath = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (fs->get_directory()));
 
                 run_command_indir (cmdline_text, fpath, term);
                 g_free (fpath);
@@ -164,7 +161,7 @@ static void on_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs, GnomeCm
     g_return_if_fail (GNOME_CMD_IS_FILE_SELECTOR (fs));
     g_return_if_fail (GNOME_CMD_IS_CMDLINE (cmdline));
 
-    gchar *dpath = gnome_cmd_dir_get_display_path (gnome_cmd_file_selector_get_directory (fs));
+    gchar *dpath = gnome_cmd_dir_get_display_path (fs->get_directory());
     gnome_cmd_cmdline_set_dir (cmdline, dpath);
     g_free (dpath);
 }
@@ -283,14 +280,14 @@ GtkWidget *gnome_cmd_cmdline_new ()
 {
     GnomeCmdCmdline *cmdline = (GnomeCmdCmdline *) gtk_type_new (gnome_cmd_cmdline_get_type ());
 
-    gnome_cmd_cmdline_set_history (cmdline, gnome_cmd_data_get_cmdline_history ());
+    gnome_cmd_cmdline_set_history (cmdline, gnome_cmd_data.cmdline_history);
     update_history_combo (cmdline);
 
     return GTK_WIDGET (cmdline);
 }
 
 
-GtkType gnome_cmd_cmdline_get_type (void)
+GtkType gnome_cmd_cmdline_get_type ()
 {
     static GtkType dlg_type = 0;
 
@@ -496,13 +493,13 @@ gboolean gnome_cmd_cmdline_keypressed (GnomeCmdCmdline *cmdline, GdkEventKey *ev
                             GtkWidget *file_list = fs->list_widget;
 
                             gtk_widget_grab_focus (file_list);
-                            gnome_cmd_file_selector_set_active (fs, TRUE);
+                            fs->set_active(TRUE);
 
                             gtk_signal_emit_by_name (GTK_OBJECT (file_list), "key-press-event", &event2, &ret);
                             event->keyval = 0;
                         }
                         break;
-            }
+                }
 
     return FALSE;
 }
