@@ -1,6 +1,7 @@
 /*
-    GNOME Commander - A GNOME based file manager 
+    GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,15 +15,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
-#ifndef __GNOME_CMD_PREPARE_DEL_DIALOG_H__
-#define __GNOME_CMD_PREPARE_DEL_DIALOG_H__
-
-
-void
-gnome_cmd_delete_dialog_show (GList *files);
-
-#endif //__GNOME_CMD_PREPARE_DEL_DIALOG_H__
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+#ifndef __GNOME_CMD_DELETE_DIALOG_H__
+#define __GNOME_CMD_DELETE_DIALOG_H__
 
+void gnome_cmd_delete_dialog_show (GList *files);
 
+#endif // __GNOME_CMD_DELETE_DIALOG_H__
