@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +24,7 @@
 #include "gnome-cmd-key-shortcuts-dialog.h"
 #include "eggcellrendererkeys.h"
 #include "gnome-cmd-data.h"
+#include "gnome-cmd-treeview.h"
 #include "gnome-cmd-hintbox.h"
 #include "dict.h"
 #include "utils.h"
@@ -36,17 +38,13 @@ using namespace std;
 #define GNOME_CMD_IS_KEY_SHORTCUTS_DIALOG(obj)       (G_TYPE_INSTANCE_CHECK_TYPE ((obj), GNOME_CMD_TYPE_KEY_SHORTCUTS_DIALOG)
 
 
-typedef struct _GnomeCmdKeyShortcutsDialog GnomeCmdKeyShortcutsDialog;
-typedef struct _GnomeCmdKeyShortcutsDialogClass GnomeCmdKeyShortcutsDialogClass;
-
-
 struct GnomeCmdKeyShortcutsDialogPrivate
 {
     GnomeCmdKeyShortcutsDialogPrivate();
 };
 
 
-struct _GnomeCmdKeyShortcutsDialog
+struct GnomeCmdKeyShortcutsDialog
 {
     GtkDialog parent;
 
@@ -56,7 +54,7 @@ struct _GnomeCmdKeyShortcutsDialog
 };
 
 
-struct _GnomeCmdKeyShortcutsDialogClass
+struct GnomeCmdKeyShortcutsDialogClass
 {
     GtkDialogClass parent_class;
 };
@@ -67,7 +65,7 @@ inline GnomeCmdKeyShortcutsDialogPrivate::GnomeCmdKeyShortcutsDialogPrivate()
 }
 
 
-GnomeCmdUserActions *_GnomeCmdKeyShortcutsDialog::user_actions = NULL;
+GnomeCmdUserActions *GnomeCmdKeyShortcutsDialog::user_actions = NULL;
 
 
 G_DEFINE_TYPE (GnomeCmdKeyShortcutsDialog, gnome_cmd_key_shortcuts_dialog, GTK_TYPE_DIALOG)
@@ -265,36 +263,6 @@ gboolean gnome_cmd_key_shortcuts_dialog_new (GnomeCmdUserActions &user_actions)
 }
 
 
-inline GtkTreeViewColumn *create_new_text_column (GtkTreeView *view, GtkCellRenderer *&renderer, gint COL_ID, const gchar *title=NULL)
-{
-    renderer = gtk_cell_renderer_text_new ();
-
-    GtkTreeViewColumn *col = gtk_tree_view_column_new_with_attributes (title,
-                                                                       renderer,
-                                                                       "text", COL_ID,
-                                                                       NULL);
-    g_object_set (col,
-                  "clickable", TRUE,
-                  "resizable", TRUE,
-                  NULL);
-
-    g_object_set_data (G_OBJECT (renderer), "column", GINT_TO_POINTER (COL_ID));
-
-    // pack tree view column into tree view
-    gtk_tree_view_append_column (GTK_TREE_VIEW (view), col);
-
-    return col;
-}
-
-
-inline GtkTreeViewColumn *create_new_text_column (GtkTreeView *view, gint COL_ID, const gchar *title=NULL)
-{
-    GtkCellRenderer *renderer = NULL;
-
-    return create_new_text_column (view, renderer, COL_ID, title);
-}
-
-
 inline GtkTreeViewColumn *create_new_accel_column (GtkTreeView *view, GtkCellRenderer *&renderer, gint COL_KEYS_ID, gint COL_MODS_ID, const gchar *title=NULL)
 {
     renderer = egg_cell_renderer_keys_new ();
@@ -388,7 +356,7 @@ inline GtkWidget *create_view_and_model (GnomeCmdUserActions &user_actions)
 
     g_object_unref (combo_model);          // destroy model automatically with view
 
-    col = create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_OPTION, _("Options"));
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_OPTION, _("Options"));
     gtk_tooltips_set_tip (tips, col->button, _("Optional data"), NULL);
     gtk_tree_view_column_set_sort_column_id (col, SORTID_OPTION);
     g_signal_connect(renderer, "edited", (GCallback) cell_edited_callback, view);
@@ -656,7 +624,8 @@ static void add_clicked_callback (GtkButton *button, GtkWidget *view)
 
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                        COL_ACTION, _("Do nothing"),                                                                    // FIXME: temporarily, use "no.action" -> _("Do nothing")
+                        COL_ACTION, _("Do nothing"),
+                        COL_NAME, "no.action",
                         -1);
 
     GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
