@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,16 +29,12 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_xfer_progress_win_get_type ())
 
 
-typedef struct _GnomeCmdXferProgressWin GnomeCmdXferProgressWin;
-typedef struct _GnomeCmdXferProgressWinClass GnomeCmdXferProgressWinClass;
-
-
-
-struct _GnomeCmdXferProgressWin
+struct GnomeCmdXferProgressWin
 {
     GtkWindow parent;
 
     GtkWidget *totalprog;
+    GtkWidget *fileprog;
     GtkWidget *msg_label;
     GtkWidget *fileprog_label;
 
@@ -45,29 +42,24 @@ struct _GnomeCmdXferProgressWin
 };
 
 
-struct _GnomeCmdXferProgressWinClass
+struct GnomeCmdXferProgressWinClass
 {
     GtkWindowClass parent_class;
 };
 
 
-GtkWidget*
-gnome_cmd_xfer_progress_win_new (void);
+GtkWidget *gnome_cmd_xfer_progress_win_new (guint no_of_files=0);
 
-GtkType
-gnome_cmd_xfer_progress_win_get_type (void);
+GtkType gnome_cmd_xfer_progress_win_get_type ();
 
-void
-gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *win,
-                                                GnomeVFSFileSize bytes_copied,
-                                                GnomeVFSFileSize bytes_total);
+void gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *win,
+                                                     GnomeVFSFileSize file_bytes_copied,
+                                                     GnomeVFSFileSize file_size,
+                                                     GnomeVFSFileSize bytes_copied,
+                                                     GnomeVFSFileSize bytes_total);
 
-void
-gnome_cmd_xfer_progress_win_set_msg (GnomeCmdXferProgressWin *win,
-                                     const gchar *string);
+void gnome_cmd_xfer_progress_win_set_msg (GnomeCmdXferProgressWin *win, const gchar *string);
 
-void
-gnome_cmd_xfer_progress_win_set_action (GnomeCmdXferProgressWin *win,
-                                        const gchar *string);
+void gnome_cmd_xfer_progress_win_set_action (GnomeCmdXferProgressWin *win, const gchar *string);
 
 #endif // __GNOME_CMD_XFER_PROGRESS_WIN_H__
