@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,18 +23,14 @@
 
 #include "gnome-cmd-file.h"
 
-G_BEGIN_DECLS
-
-typedef struct
+struct LsColor
 {
     GnomeVFSFileType type;
     gchar *ext;
     GdkColor *fg, *bg;
-} LsColor;
+};
 
-void     ls_colors_init (void);
-LsColor *ls_colors_get (GnomeCmdFile *finfo);
-
-G_END_DECLS
+void     ls_colors_init ();
+LsColor *ls_colors_get (GnomeCmdFile *f);
 
 #endif // __LS_COLORS_H__
